package org.apache.bcel.generic;

import java.io.DataOutputStream;
import java.io.IOException;
import org.apache.bcel.util.ByteSequence;

/* loaded from: org_apache_bcel_generic.jar:org/apache/bcel/generic/LocalVariableInstruction.class */
public abstract class LocalVariableInstruction extends Instruction implements TypedInstruction, IndexedInstruction {

    @Deprecated
    protected int n;
    private short cTag;
    private short canonTag;

    /* JADX INFO: Access modifiers changed from: package-private */
    public LocalVariableInstruction() {
        this.n = -1;
        this.cTag = (short) -1;
        this.canonTag = (short) -1;
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public LocalVariableInstruction(short canonTag, short cTag) {
        this.n = -1;
        this.cTag = (short) -1;
        this.canonTag = (short) -1;
        this.canonTag = canonTag;
        this.cTag = cTag;
    }

    /* JADX INFO: Access modifiers changed from: protected */
    public LocalVariableInstruction(short opcode, short cTag, int n) {
        super(opcode, (short) 2);
        this.n = -1;
        this.cTag = (short) -1;
        this.canonTag = (short) -1;
        this.cTag = cTag;
        this.canonTag = opcode;
        setIndex(n);
    }

    @Override // org.apache.bcel.generic.Instruction
    public void dump(DataOutputStream out) throws IOException {
        if (wide()) {
            out.writeByte(196);
        }
        out.writeByte(super.getOpcode());
        if (super.getLength() > 1) {
            if (wide()) {
                out.writeShort(this.n);
            } else {
                out.writeByte(this.n);
            }
        }
    }

    public short getCanonicalTag() {
        return this.canonTag;
    }

    @Override // org.apache.bcel.generic.IndexedInstruction
    public final int getIndex() {
        return this.n;
    }

    public Type getType(ConstantPoolGen cp) {
        switch (this.canonTag) {
            case 21:
            case 54:
                return Type.INT;
            case 22:
            case 55:
                return Type.LONG;
            case 23:
            case 56:
                return Type.FLOAT;
            case 24:
            case 57:
                return Type.DOUBLE;
            case 25:
            case 58:
                return Type.OBJECT;
            case 26:
            case 27:
            case 28:
            case 29:
            case 30:
            case 31:
            case 32:
            case 33:
            case 34:
            case 35:
            case 36:
            case 37:
            case 38:
            case 39:
            case 40:
            case 41:
            case 42:
            case 43:
            case 44:
            case 45:
            case 46:
            case 47:
            case 48:
            case 49:
            case 50:
            case 51:
            case 52:
            case 53:
            default:
                throw new ClassGenException("Unknown case in switch" + ((int) this.canonTag));
        }
    }

    @Override // org.apache.bcel.generic.Instruction
    protected void initFromFile(ByteSequence bytes, boolean wide) throws IOException {
        if (wide) {
            this.n = bytes.readUnsignedShort();
            super.setLength(4);
            return;
        }
        short opcode = super.getOpcode();
        if ((opcode >= 21 && opcode <= 25) || (opcode >= 54 && opcode <= 58)) {
            this.n = bytes.readUnsignedByte();
            super.setLength(2);
        } else {
            if (opcode <= 45) {
                this.n = (opcode - 26) % 4;
            } else {
                this.n = (opcode - 59) % 4;
            }
            super.setLength(1);
        }
    }

    public void setIndex(int n) {
        if (n < 0 || n > 65535) {
            throw new ClassGenException("Illegal value: " + n);
        }
        this.n = n;
        if (n <= 3) {
            super.setOpcode((short) (this.cTag + n));
            super.setLength(1);
            return;
        }
        super.setOpcode(this.canonTag);
        if (wide()) {
            super.setLength(4);
        } else {
            super.setLength(2);
        }
    }

    /* JADX INFO: Access modifiers changed from: package-private */
    public final void setIndexOnly(int n) {
        this.n = n;
    }

    @Override // org.apache.bcel.generic.Instruction
    public String toString(boolean verbose) {
        short opcode = super.getOpcode();
        if ((opcode >= 26 && opcode <= 45) || (opcode >= 59 && opcode <= 78)) {
            return super.toString(verbose);
        }
        return super.toString(verbose) + " " + this.n;
    }

    private boolean wide() {
        return this.n > 255;
    }
}
